@@ -215,15 +215,15 @@ def restart(): ...
 
 
 # same as ac.isCarInPitline()
-def isCarInPitlane(): ...
+def isCarInPitlane(car_id): ...
 
 
 # same as ac.isCarInPitlane()
-def isCarInPitline(): ...
+def isCarInPitline(car_id): ...
 
 
 # noticed in the SimHub mod
-def isCarInPit(): ...
+def isCarInPit(car_id): ...
 
 
 def getCarSkin(car_id): ...
